Index: src/Common/utility.h
===================================================================
--- src/Common/utility.h	(revision 8633f060401360e1474381d3c48aac806644c2ab)
+++ src/Common/utility.h	(revision 57acae0dd55a32107fc1c3e35f161b499e5bbf1e)
@@ -10,6 +10,6 @@
 // Created On       : Mon May 18 07:44:20 2015
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Thu Apr 19 16:21:44 2018
-// Update Count     : 37
+// Last Modified On : Fri Apr 20 22:35:33 2018
+// Update Count     : 38
 //
 
@@ -437,9 +437,9 @@
 
 // -----------------------------------------------------------------------------
 // O(1) polymorphic integer log2, using clz, which returns the number of leading 0-bits, starting at the most
 // significant bit (single instruction on x86)
 
 template<typename T>
-inline constexpr T log2(const T & t) {
+inline constexpr T ilog2(const T & t) {
 	if ( std::is_integral<T>::value ) {
 		const constexpr int r = sizeof(t) * __CHAR_BIT__ - 1;
@@ -449,5 +449,5 @@
 	} // if
 	return -1;
-}
+} // ilong2
 
 
@@ -437,9 +437,9 @@
 
 // -----------------------------------------------------------------------------
-// O(1) polymorphic integer log2, using clz, which returns the number of leading 0-bits, starting at the most
+// O(1) polymorphic integer ilog2, using clz, which returns the number of leading 0-bits, starting at the most
 // significant bit (single instruction on x86)
 
